@@ -1,6 +1,6 @@
 package Data::Riak::HTTP::Request;
 {
-  $Data::Riak::HTTP::Request::VERSION = '0.10';
+  $Data::Riak::HTTP::Request::VERSION = '0.2';
 }
 
 use strict;
@@ -43,11 +43,6 @@ has links => (
     }
 );
 
-has indexes => (
-    is => 'ro',
-    isa => 'ArrayRef[HashRef]'
-);
-
 has content_type => (
     is => 'ro',
     isa => 'Str',
@@ -75,7 +70,7 @@ Data::Riak::HTTP::Request
 
 =head1 VERSION
 
-version 0.10
+version 0.2
 
 =head1 AUTHOR
 
