@@ -1,6 +1,6 @@
 package Data::Riak::MapReduce;
 {
-  $Data::Riak::MapReduce::VERSION = '0.10';
+  $Data::Riak::MapReduce::VERSION = '0.2';
 }
 
 use strict;
@@ -20,7 +20,7 @@ with 'Data::Riak::Role::HasRiak';
 
 has inputs => (
     is => 'ro',
-    isa => 'ArrayRef | Str | HashRef',
+    isa => 'ArrayRef | Str',
     required => 1
 );
 
@@ -64,7 +64,7 @@ Data::Riak::MapReduce - A map/reduce query
 
 =head1 VERSION
 
-version 0.10
+version 0.2
 
 =head1 SYNOPSIS
 
